#ifndef MSP_GL_TEXTURE1D_H_
#define MSP_GL_TEXTURE1D_H_

#include "texture.h"

namespace Msp {
namespace GL {

class Texture1D: public Texture
{
public:
	class Loader: public DataFile::DerivedObjectLoader<Texture1D, Texture::Loader>
	{
	public:
		Loader(Texture1D &);
		Loader(Texture1D &, Collection &);
	private:
		void init();

		void raw_data(const std::string &);
		void storage(PixelFormat, unsigned);
	};

private:
	unsigned width;
	unsigned levels;
	unsigned allocated;

public:
	Texture1D();

	void storage(PixelFormat, unsigned, unsigned = 0);
	void allocate(unsigned);
	void image(unsigned, PixelFormat, DataType, const void *);
	void sub_image(unsigned, int, unsigned, PixelFormat, DataType, const void *);
	virtual void image(const Graphics::Image &, bool = false);
	unsigned get_width() const { return width; }

private:
	unsigned get_n_levels() const;
	unsigned get_level_size(unsigned) const;

public:
	virtual AsyncLoader *load(IO::Seekable &, const Resources * = 0) { return 0; }
	virtual UInt64 get_data_size() const;
	virtual void unload() { }
};

} // namespace GL
} // namespace Msp

#endif
